@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkAxisExtended.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkAxisExtended
  * @brief   extended axis tick positioning
@@ -33,6 +21,7 @@
 #include "vtkObject.h"
 #include "vtkVector.h" // Needed for vtkVector
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCHARTSCORE_EXPORT vtkAxisExtended : public vtkObject
 {
 public:
@@ -136,3 +125,4 @@ private:
   vtkAxisExtended(const vtkAxisExtended&) = delete;
   void operator=(const vtkAxisExtended&) = delete;
 };
+VTK_ABI_NAMESPACE_END
