@@ -7,7 +7,7 @@
 #  define VTKCHARTSCORE_NO_EXPORT
 #else
 #  ifndef VTKCHARTSCORE_EXPORT
-#    ifdef vtkChartsCore_EXPORTS
+#    ifdef ChartsCore_EXPORTS
         /* We are building this library */
 #      define VTKCHARTSCORE_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,27 +23,38 @@
 
 #ifndef VTKCHARTSCORE_DEPRECATED
 #  define VTKCHARTSCORE_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKCHARTSCORE_DEPRECATED_EXPORT VTKCHARTSCORE_EXPORT __attribute__ ((__deprecated__))
-#  define VTKCHARTSCORE_DEPRECATED_NO_EXPORT VTKCHARTSCORE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKCHARTSCORE_NO_DEPRECATED
+#ifndef VTKCHARTSCORE_DEPRECATED_EXPORT
+#  define VTKCHARTSCORE_DEPRECATED_EXPORT VTKCHARTSCORE_EXPORT VTKCHARTSCORE_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersGeneralModule.h"
+#ifndef VTKCHARTSCORE_DEPRECATED_NO_EXPORT
+#  define VTKCHARTSCORE_DEPRECATED_NO_EXPORT VTKCHARTSCORE_NO_EXPORT VTKCHARTSCORE_DEPRECATED
+#endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKCHARTSCORE_NO_DEPRECATED
+#    define VTKCHARTSCORE_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkChartsCoreModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+/* AutoInit dependencies. */
 #include "vtkRenderingContext2DModule.h"
 #include "vtkRenderingCoreModule.h"
 
-/* AutoInit implementations.  */
-#if defined(vtkChartsCore_INCLUDE)
-# include vtkChartsCore_INCLUDE
+
+/* AutoInit implementations. */
+#ifdef vtkChartsCore_AUTOINIT_INCLUDE
+#include vtkChartsCore_AUTOINIT_INCLUDE
 #endif
-#if defined(vtkChartsCore_AUTOINIT)
-# include "vtkAutoInit.h"
-VTK_AUTOINIT(vtkChartsCore)
+#ifdef vtkChartsCore_AUTOINIT
+#include "vtkAutoInit.h"
+VTK_MODULE_AUTOINIT(vtkChartsCore)
 #endif
 
-#endif
+#endif /* VTKCHARTSCORE_EXPORT_H */
