@@ -7,7 +7,7 @@
 #  define VTKCOMMONCORE_NO_EXPORT
 #else
 #  ifndef VTKCOMMONCORE_EXPORT
-#    ifdef vtkCommonCore_EXPORTS
+#    ifdef CommonCore_EXPORTS
         /* We are building this library */
 #      define VTKCOMMONCORE_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,25 @@
 
 #ifndef VTKCOMMONCORE_DEPRECATED
 #  define VTKCOMMONCORE_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKCOMMONCORE_DEPRECATED_EXPORT VTKCOMMONCORE_EXPORT __attribute__ ((__deprecated__))
-#  define VTKCOMMONCORE_DEPRECATED_NO_EXPORT VTKCOMMONCORE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKCOMMONCORE_NO_DEPRECATED
+#ifndef VTKCOMMONCORE_DEPRECATED_EXPORT
+#  define VTKCOMMONCORE_DEPRECATED_EXPORT VTKCOMMONCORE_EXPORT VTKCOMMONCORE_DEPRECATED
 #endif
 
-
-
+#ifndef VTKCOMMONCORE_DEPRECATED_NO_EXPORT
+#  define VTKCOMMONCORE_DEPRECATED_NO_EXPORT VTKCOMMONCORE_NO_EXPORT VTKCOMMONCORE_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKCOMMONCORE_NO_DEPRECATED
+#    define VTKCOMMONCORE_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkCommonCoreModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKCOMMONCORE_EXPORT_H */
