@@ -7,7 +7,7 @@
 #  define VTKCOMMONMISC_NO_EXPORT
 #else
 #  ifndef VTKCOMMONMISC_EXPORT
-#    ifdef vtkCommonMisc_EXPORTS
+#    ifdef CommonMisc_EXPORTS
         /* We are building this library */
 #      define VTKCOMMONMISC_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,25 @@
 
 #ifndef VTKCOMMONMISC_DEPRECATED
 #  define VTKCOMMONMISC_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKCOMMONMISC_DEPRECATED_EXPORT VTKCOMMONMISC_EXPORT __attribute__ ((__deprecated__))
-#  define VTKCOMMONMISC_DEPRECATED_NO_EXPORT VTKCOMMONMISC_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKCOMMONMISC_NO_DEPRECATED
+#ifndef VTKCOMMONMISC_DEPRECATED_EXPORT
+#  define VTKCOMMONMISC_DEPRECATED_EXPORT VTKCOMMONMISC_EXPORT VTKCOMMONMISC_DEPRECATED
 #endif
 
-
-
+#ifndef VTKCOMMONMISC_DEPRECATED_NO_EXPORT
+#  define VTKCOMMONMISC_DEPRECATED_NO_EXPORT VTKCOMMONMISC_NO_EXPORT VTKCOMMONMISC_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKCOMMONMISC_NO_DEPRECATED
+#    define VTKCOMMONMISC_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkCommonMiscModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKCOMMONMISC_EXPORT_H */
