@@ -38,6 +38,11 @@
 #    define VTKDOMAINSCHEMISTRYOPENGL2_NO_DEPRECATED
 #  endif
 #endif
+
+/* VTK-HeaderTest-Exclude: vtkDomainsChemistryOpenGL2Module.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
 /* AutoInit dependencies. */
 #include "vtkDomainsChemistryModule.h"
 #include "vtkRenderingOpenGL2Module.h"
