@@ -7,7 +7,7 @@
 #  define VTKFILTERSGENERIC_NO_EXPORT
 #else
 #  ifndef VTKFILTERSGENERIC_EXPORT
-#    ifdef vtkFiltersGeneric_EXPORTS
+#    ifdef FiltersGeneric_EXPORTS
         /* We are building this library */
 #      define VTKFILTERSGENERIC_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,17 +23,25 @@
 
 #ifndef VTKFILTERSGENERIC_DEPRECATED
 #  define VTKFILTERSGENERIC_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKFILTERSGENERIC_DEPRECATED_EXPORT VTKFILTERSGENERIC_EXPORT __attribute__ ((__deprecated__))
-#  define VTKFILTERSGENERIC_DEPRECATED_NO_EXPORT VTKFILTERSGENERIC_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKFILTERSGENERIC_NO_DEPRECATED
+#ifndef VTKFILTERSGENERIC_DEPRECATED_EXPORT
+#  define VTKFILTERSGENERIC_DEPRECATED_EXPORT VTKFILTERSGENERIC_EXPORT VTKFILTERSGENERIC_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersCoreModule.h"
-#include "vtkFiltersSourcesModule.h"
-
+#ifndef VTKFILTERSGENERIC_DEPRECATED_NO_EXPORT
+#  define VTKFILTERSGENERIC_DEPRECATED_NO_EXPORT VTKFILTERSGENERIC_NO_EXPORT VTKFILTERSGENERIC_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKFILTERSGENERIC_NO_DEPRECATED
+#    define VTKFILTERSGENERIC_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkFiltersGenericModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKFILTERSGENERIC_EXPORT_H */
