@@ -7,7 +7,7 @@
 #  define VTKFILTERSHYPERTREE_NO_EXPORT
 #else
 #  ifndef VTKFILTERSHYPERTREE_EXPORT
-#    ifdef vtkFiltersHyperTree_EXPORTS
+#    ifdef FiltersHyperTree_EXPORTS
         /* We are building this library */
 #      define VTKFILTERSHYPERTREE_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,25 @@
 
 #ifndef VTKFILTERSHYPERTREE_DEPRECATED
 #  define VTKFILTERSHYPERTREE_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKFILTERSHYPERTREE_DEPRECATED_EXPORT VTKFILTERSHYPERTREE_EXPORT __attribute__ ((__deprecated__))
-#  define VTKFILTERSHYPERTREE_DEPRECATED_NO_EXPORT VTKFILTERSHYPERTREE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKFILTERSHYPERTREE_NO_DEPRECATED
+#ifndef VTKFILTERSHYPERTREE_DEPRECATED_EXPORT
+#  define VTKFILTERSHYPERTREE_DEPRECATED_EXPORT VTKFILTERSHYPERTREE_EXPORT VTKFILTERSHYPERTREE_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersCoreModule.h"
-
+#ifndef VTKFILTERSHYPERTREE_DEPRECATED_NO_EXPORT
+#  define VTKFILTERSHYPERTREE_DEPRECATED_NO_EXPORT VTKFILTERSHYPERTREE_NO_EXPORT VTKFILTERSHYPERTREE_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKFILTERSHYPERTREE_NO_DEPRECATED
+#    define VTKFILTERSHYPERTREE_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkFiltersHyperTreeModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKFILTERSHYPERTREE_EXPORT_H */
