@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkFiltersParallelFlowPathsObjectFactory.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #ifndef vtkFiltersParallelFlowPathsObjectFactory_h
 #define vtkFiltersParallelFlowPathsObjectFactory_h
@@ -19,11 +7,13 @@
 #include "vtkFiltersParallelFlowPathsModule.h" // For export macro
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
+
 class VTKFILTERSPARALLELFLOWPATHS_EXPORT vtkFiltersParallelFlowPathsObjectFactory : public vtkObjectFactory
 {
 public:
   static vtkFiltersParallelFlowPathsObjectFactory * New();
-  vtkTypeMacro(vtkFiltersParallelFlowPathsObjectFactory, vtkObjectFactory)
+  vtkTypeMacro(vtkFiltersParallelFlowPathsObjectFactory, vtkObjectFactory);
 
   const char * GetDescription() override { return "vtkFiltersParallelFlowPaths factory overrides."; }
 
@@ -39,4 +29,6 @@ private:
   void operator=(const vtkFiltersParallelFlowPathsObjectFactory&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
+
 #endif // vtkFiltersParallelFlowPathsObjectFactory_h
