@@ -39,6 +39,11 @@
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkIOChemistryModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 /* AutoInit implementations. */
 #ifdef vtkIOChemistry_AUTOINIT_INCLUDE
 #include vtkIOChemistry_AUTOINIT_INCLUDE
