@@ -7,7 +7,7 @@
 #  define VTKIOFFMPEG_NO_EXPORT
 #else
 #  ifndef VTKIOFFMPEG_EXPORT
-#    ifdef vtkIOFFMPEG_EXPORTS
+#    ifdef IOFFMPEG_EXPORTS
         /* We are building this library */
 #      define VTKIOFFMPEG_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,25 @@
 
 #ifndef VTKIOFFMPEG_DEPRECATED
 #  define VTKIOFFMPEG_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKIOFFMPEG_DEPRECATED_EXPORT VTKIOFFMPEG_EXPORT __attribute__ ((__deprecated__))
-#  define VTKIOFFMPEG_DEPRECATED_NO_EXPORT VTKIOFFMPEG_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKIOFFMPEG_NO_DEPRECATED
+#ifndef VTKIOFFMPEG_DEPRECATED_EXPORT
+#  define VTKIOFFMPEG_DEPRECATED_EXPORT VTKIOFFMPEG_EXPORT VTKIOFFMPEG_DEPRECATED
 #endif
 
-
-
+#ifndef VTKIOFFMPEG_DEPRECATED_NO_EXPORT
+#  define VTKIOFFMPEG_DEPRECATED_NO_EXPORT VTKIOFFMPEG_NO_EXPORT VTKIOFFMPEG_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKIOFFMPEG_NO_DEPRECATED
+#    define VTKIOFFMPEG_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkIOFFMPEGModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKIOFFMPEG_EXPORT_H */
