@@ -7,7 +7,7 @@
 #  define VTKIOGDAL_NO_EXPORT
 #else
 #  ifndef VTKIOGDAL_EXPORT
-#    ifdef vtkIOGDAL_EXPORTS
+#    ifdef IOGDAL_EXPORTS
         /* We are building this library */
 #      define VTKIOGDAL_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,25 @@
 
 #ifndef VTKIOGDAL_DEPRECATED
 #  define VTKIOGDAL_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKIOGDAL_DEPRECATED_EXPORT VTKIOGDAL_EXPORT __attribute__ ((__deprecated__))
-#  define VTKIOGDAL_DEPRECATED_NO_EXPORT VTKIOGDAL_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKIOGDAL_NO_DEPRECATED
+#ifndef VTKIOGDAL_DEPRECATED_EXPORT
+#  define VTKIOGDAL_DEPRECATED_EXPORT VTKIOGDAL_EXPORT VTKIOGDAL_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkIOImageModule.h"
-
+#ifndef VTKIOGDAL_DEPRECATED_NO_EXPORT
+#  define VTKIOGDAL_DEPRECATED_NO_EXPORT VTKIOGDAL_NO_EXPORT VTKIOGDAL_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKIOGDAL_NO_DEPRECATED
+#    define VTKIOGDAL_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkIOGDALModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKIOGDAL_EXPORT_H */
