@@ -38,6 +38,11 @@
 #    define VTKIOMYSQL_NO_DEPRECATED
 #  endif
 #endif
+
+/* VTK-HeaderTest-Exclude: vtkIOMySQLModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
 /* AutoInit dependencies. */
 #include "vtkIOSQLModule.h"
 
