@@ -7,7 +7,7 @@
 #  define VTKINFOVISBOOSTGRAPHALGORITHMS_NO_EXPORT
 #else
 #  ifndef VTKINFOVISBOOSTGRAPHALGORITHMS_EXPORT
-#    ifdef vtkInfovisBoostGraphAlgorithms_EXPORTS
+#    ifdef InfovisBoostGraphAlgorithms_EXPORTS
         /* We are building this library */
 #      define VTKINFOVISBOOSTGRAPHALGORITHMS_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,25 @@
 
 #ifndef VTKINFOVISBOOSTGRAPHALGORITHMS_DEPRECATED
 #  define VTKINFOVISBOOSTGRAPHALGORITHMS_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKINFOVISBOOSTGRAPHALGORITHMS_DEPRECATED_EXPORT VTKINFOVISBOOSTGRAPHALGORITHMS_EXPORT __attribute__ ((__deprecated__))
-#  define VTKINFOVISBOOSTGRAPHALGORITHMS_DEPRECATED_NO_EXPORT VTKINFOVISBOOSTGRAPHALGORITHMS_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKINFOVISBOOSTGRAPHALGORITHMS_NO_DEPRECATED
+#ifndef VTKINFOVISBOOSTGRAPHALGORITHMS_DEPRECATED_EXPORT
+#  define VTKINFOVISBOOSTGRAPHALGORITHMS_DEPRECATED_EXPORT VTKINFOVISBOOSTGRAPHALGORITHMS_EXPORT VTKINFOVISBOOSTGRAPHALGORITHMS_DEPRECATED
 #endif
 
-
-
+#ifndef VTKINFOVISBOOSTGRAPHALGORITHMS_DEPRECATED_NO_EXPORT
+#  define VTKINFOVISBOOSTGRAPHALGORITHMS_DEPRECATED_NO_EXPORT VTKINFOVISBOOSTGRAPHALGORITHMS_NO_EXPORT VTKINFOVISBOOSTGRAPHALGORITHMS_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKINFOVISBOOSTGRAPHALGORITHMS_NO_DEPRECATED
+#    define VTKINFOVISBOOSTGRAPHALGORITHMS_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkInfovisBoostGraphAlgorithmsModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKINFOVISBOOSTGRAPHALGORITHMS_EXPORT_H */
