@@ -7,7 +7,7 @@
 #  define VTKINTERACTIONIMAGE_NO_EXPORT
 #else
 #  ifndef VTKINTERACTIONIMAGE_EXPORT
-#    ifdef vtkInteractionImage_EXPORTS
+#    ifdef InteractionImage_EXPORTS
         /* We are building this library */
 #      define VTKINTERACTIONIMAGE_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,19 +23,25 @@
 
 #ifndef VTKINTERACTIONIMAGE_DEPRECATED
 #  define VTKINTERACTIONIMAGE_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKINTERACTIONIMAGE_DEPRECATED_EXPORT VTKINTERACTIONIMAGE_EXPORT __attribute__ ((__deprecated__))
-#  define VTKINTERACTIONIMAGE_DEPRECATED_NO_EXPORT VTKINTERACTIONIMAGE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKINTERACTIONIMAGE_NO_DEPRECATED
+#ifndef VTKINTERACTIONIMAGE_DEPRECATED_EXPORT
+#  define VTKINTERACTIONIMAGE_DEPRECATED_EXPORT VTKINTERACTIONIMAGE_EXPORT VTKINTERACTIONIMAGE_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkInteractionStyleModule.h"
-#include "vtkInteractionWidgetsModule.h"
-#include "vtkRenderingCoreModule.h"
-#include "vtkRenderingFreeTypeModule.h"
-
+#ifndef VTKINTERACTIONIMAGE_DEPRECATED_NO_EXPORT
+#  define VTKINTERACTIONIMAGE_DEPRECATED_NO_EXPORT VTKINTERACTIONIMAGE_NO_EXPORT VTKINTERACTIONIMAGE_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKINTERACTIONIMAGE_NO_DEPRECATED
+#    define VTKINTERACTIONIMAGE_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkInteractionImageModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKINTERACTIONIMAGE_EXPORT_H */
