@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkOpenGLFramebufferObject.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkOpenGLFramebufferObject
  * @brief   Internal class which encapsulates OpenGL FramebufferObject
@@ -22,7 +10,7 @@
  * framebuffer such as created with a standard window/context or
  * it can be a user created Framebuffer objects. When draw and read
  * commands are invoked, they apply to the current draw and/or read
- * frambuffers.
+ * framebuffers.
  *
  * A framebuffer consists of color buffers and an optional depth buffer.
  * The FramebufferObject does not hold the memory for these buffers, it
@@ -46,8 +34,7 @@
  * have draw and read framebuffer objects (bindings) and then for the currently
  * bound FramebufferObjects you have active draw and read buffers.
  *
- * A single FramebufferObject can be bound to both Draw and Read. Likewise
- * a single buffer can be activated for both draw and read operations. You
+ * A single FramebufferObject can be bound to both Draw and Read. You
  * cannot assign and activate a TextureObject for drawing on the FO and
  * at the same time pass it in as a Texture to the shader program. That
  * type of operation is very common and must be done in two steps.
@@ -61,7 +48,6 @@
  * fbo->SetContext(renWin);
  * fbo->SaveCurrentBindingsAndBuffers();
  * fbo->PopulateFramebuffer(width, height);
- * fbo->Start();
  *
  * ...
  *
@@ -77,7 +63,6 @@
  * fbo->AddColorAttachment(0, vtkTextureObj);
  * fbo->AddDepthAttachment(); // auto create depth buffer
  * fbo->ActivateBuffer(0);
- * fbo->Start();
  *
  * ...
  *
@@ -85,14 +70,13 @@
  *\endcode
  *
  * If you will be using a FO repeatedly then it is best to create it
- * attach the bufffers and then use as needed for example
+ * attach the buffers and then use as needed for example
  *
  * Typical use case:
  *\code{.cpp}
  * // setup the FBO once
  * fbo->SetContext(renWin);
  * fbo->SaveCurrentBindingsAndBuffers();
- * fbo->Bind();
  * fbo->AddColorAttachment(0, vtkTextureObj);
  * fbo->AddDepthAttachment(); // auto create depth buffer
  * fbo->RestorePreviousBindingsAndBuffers();
@@ -101,13 +85,12 @@
  * fbo->SaveCurrentBindingsAndBuffers();
  * fbo->Bind();
  * fbo->ActivateBuffer(0);
- * fbo->Start();
  * ... // render here etc
  * fbo->RestorePreviousBindingsAndBuffers();
  *\endcode
  *
- * If you with to only bind/attach the draw buffers or read buffers there
- * are mode specific versions of most methods that only apply to the
+ * If you with to only bind the framebuffer for drawing or reading there
+ * are mode specific versions of some methods that only apply to the
  * mode specified Draw/Read/Both. The mode argument uses OpenGL constants
  * so this class provides convenience methods to return them named
  * GetDrawMode() GetReadMode() and GetBothMode() so that your code
@@ -122,19 +105,27 @@
  * a conversion but generally it should still be easy. Use the code
  * samples above (or any of the classes in OpenGL2 that currently use FBOs)
  * to guide you. They have all been converted to this class. Where previously
- * a DepthBuffer was autmatically created for you, you now need to do it
+ * a DepthBuffer was automatically created for you, you now need to do it
  * explicitly using AddDepthAttachment().
  *
- * This class should be named vtkOpenGLFramebufferObject (FO)
  * Note the capitalization of FramebufferObject
  *
  * @sa
  * vtkTextureObject, vtkRenderbufferObject
-*/
+ */
 
 #ifndef vtkOpenGLFramebufferObject_h
 #define vtkOpenGLFramebufferObject_h
 
+/* Dec 2018 this class has been cleaned up such that
+ * AddColorAttachment and AddDepthAttachment no longer
+ * take a mode argument. The mode is determined by how
+ * the framebuffer is bound. If you are using these methods
+ * and need to support both the old and new signatures you
+ * can check for the following define in your code.
+ */
+#define VTK_UPDATED_FRAMEBUFFER
+
 /**
  * A variant of vtkErrorMacro that is used to verify framebuffer
  * object completeness. It's provided so that reporting may include
@@ -142,32 +133,29 @@
  * the macro does nothing.
  */
 #ifdef NDEBUG
-# define vtkCheckFrameBufferStatusMacro(mode)
-# define vtkStaticCheckFrameBufferStatusMacro(mode)
+#define vtkCheckFrameBufferStatusMacro(mode)
+#define vtkStaticCheckFrameBufferStatusMacro(mode)
 #else
-# define vtkCheckFrameBufferStatusMacroImpl(macro, mode)           \
-{                                                                  \
-const char *eStr;                                                  \
-bool ok = vtkOpenGLFramebufferObject::GetFrameBufferStatus(mode, eStr); \
-if (!ok)                                                           \
-{                                                                \
-  macro(                                                           \
-    << "OpenGL ERROR. The FBO is incomplete : " << eStr);          \
-}                                                                \
- }
-# define vtkCheckFrameBufferStatusMacro(mode) \
-    vtkCheckFrameBufferStatusMacroImpl(vtkErrorMacro, mode)
-# define vtkStaticCheckFrameBufferStatusMacro(mode) \
-    vtkCheckFrameBufferStatusMacroImpl(vtkGenericWarningMacro, mode)
+#define vtkCheckFrameBufferStatusMacroImpl(macro, mode)                                            \
+  {                                                                                                \
+    const char* eStr;                                                                              \
+    bool ok = vtkOpenGLFramebufferObject::GetFrameBufferStatus(mode, eStr);                        \
+    if (!ok)                                                                                       \
+    {                                                                                              \
+      macro(<< "OpenGL ERROR. The FBO is incomplete : " << eStr);                                  \
+    }                                                                                              \
+  }
+#define vtkCheckFrameBufferStatusMacro(mode) vtkCheckFrameBufferStatusMacroImpl(vtkErrorMacro, mode)
+#define vtkStaticCheckFrameBufferStatusMacro(mode)                                                 \
+  vtkCheckFrameBufferStatusMacroImpl(vtkGenericWarningMacro, mode)
 #endif
 
-
 #include "vtkFrameBufferObjectBase.h"
 #include "vtkRenderingOpenGL2Module.h" // For export macro
-#include "vtkWeakPointer.h" // needed for vtkWeakPointer.
-#include <vector> // for the lists of logical buffers.
-#include <map> // for the maps
+#include <map>                         // for the maps
+#include <vector>                      // for the lists of logical buffers.
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkFOInfo;
 class vtkGenericOpenGLResourceFreeCallback;
 class vtkOpenGLRenderWindow;
@@ -186,17 +174,17 @@ public:
   vtkTypeMacro(vtkOpenGLFramebufferObject, vtkFrameBufferObjectBase);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get/Set the context. Context must be a vtkOpenGLRenderWindow.
    * This does not increase the reference count of the
    * context to avoid reference loops.
-   * SetContext() may raise an error is the OpenGL context does not support the
+   * SetContext() may raise an error if the OpenGL context does not support the
    * required OpenGL extensions.
    */
-  void SetContext(vtkRenderWindow *context);
-  vtkOpenGLRenderWindow *GetContext();
-  //@}
+  void SetContext(vtkRenderWindow* context);
+  vtkOpenGLRenderWindow* GetContext();
+  ///@}
 
   /**
    * Make the draw frame buffer active.
@@ -210,47 +198,17 @@ public:
   void UnBind();
   void UnBind(unsigned int mode);
 
-  //@{
+  ///@{
   /**
    * Store/Restore the current framebuffer bindings and buffers.
    */
-  void SaveCurrentBindings();
-  void SaveCurrentBindings(unsigned int mode);
-  void SaveCurrentBindingsAndBuffers() {
-    this->SaveCurrentBuffers();
-    this->SaveCurrentBindings();
-  }
-  void SaveCurrentBindingsAndBuffers(unsigned int mode) {
-    this->SaveCurrentBuffers(mode);
-    this->SaveCurrentBindings(mode);
-  }
-  void RestorePreviousBindings();
-  void RestorePreviousBindings(unsigned int mode);
-  void RestorePreviousBindingsAndBuffers() {
-    this->RestorePreviousBindings();
-    this->RestorePreviousBuffers();
-  }
-  void RestorePreviousBindingsAndBuffers(unsigned int mode) {
-    this->RestorePreviousBindings(mode);
-    this->RestorePreviousBuffers(mode);
-  }
-  //@}
+  void SaveCurrentBindingsAndBuffers();
+  void SaveCurrentBindingsAndBuffers(unsigned int mode);
+  void RestorePreviousBindingsAndBuffers();
+  void RestorePreviousBindingsAndBuffers(unsigned int mode);
+  ///@}
 
-  //@{
-  /**
-   * Store the current draw and read buffers. When restored
-   * only the buffers matching mode are modified.
-   * GetDrawMode() -> glDrawBuffer
-   * GetReadMode() -> glReadBuffer
-   * GetBothMode() -> both
-   */
-  void SaveCurrentBuffers();
-  void SaveCurrentBuffers(unsigned int mode);
-  void RestorePreviousBuffers();
-  void RestorePreviousBuffers(unsigned int mode);
-  //@}
-
-  //@{
+  ///@{
   /**
    * User must take care that width/height match the dimensions of
    * the user defined texture attachments.
@@ -262,29 +220,31 @@ public:
    */
   bool Start(int width, int height);
   bool StartNonOrtho(int width, int height);
-  //@}
+  ///@}
 
   /**
    * Set up ortho viewport with scissor, lighting, blend, and depth
-   * disabled. The method affects the current bound FBO. The method is
-   * static so that it may be used on the default FBO without an instance.
-   * Low level api.
+   * disabled. The method affects the current bound FBO.
    */
-  static
   void InitializeViewport(int width, int height);
 
-  //@{
+  ///@{
   // activate deactivate draw/read buffers (color buffers)
   void ActivateDrawBuffers(unsigned int n);
-  void ActivateDrawBuffers(unsigned int *ids, int n);
+  void ActivateDrawBuffers(unsigned int* ids, int n);
   void ActivateDrawBuffer(unsigned int id);
   void ActivateReadBuffer(unsigned int id);
-  void ActivateBuffer(unsigned int id) {
+  void ActivateBuffer(unsigned int id)
+  {
     this->ActivateDrawBuffer(id);
-    this->ActivateReadBuffer(id); }
+    this->ActivateReadBuffer(id);
+  }
   void DeactivateDrawBuffers();
   void DeactivateReadBuffer();
-  //@}
+  ///@}
+
+  vtkGetMacro(ActiveReadBuffer, unsigned int);
+  unsigned int GetActiveDrawBuffer(unsigned int id);
 
   /**
    * Renders a quad at the given location with pixel coordinates. This method
@@ -296,62 +256,53 @@ public:
    * \pre increasing_y: minY<=maxY
    * \pre valid_maxY: maxY<LastSize[1]
    */
-  void RenderQuad(int minX, int maxX, int minY, int maxY,
-    vtkShaderProgram *program, vtkOpenGLVertexArrayObject *vao);
+  void RenderQuad(int minX, int maxX, int minY, int maxY, vtkShaderProgram* program,
+    vtkOpenGLVertexArrayObject* vao);
 
-  //@{
+  ///@{
   /**
    * Directly assign/remove a texture to color attachments.
-   * Same as the Set methods but also does an attach call
-   * so the FO has to be bound when called.
    */
-  void AddColorAttachment(
-        unsigned int mode,
-        unsigned int attId,
-        vtkTextureObject* tex,
-        unsigned int zslice = 0);
-  void AddColorAttachment(
-        unsigned int mode,
-        unsigned int attId,
-        vtkRenderbuffer* tex);
-  void RemoveColorAttachment(unsigned int mode, unsigned int index);
-  void RemoveColorAttachments(unsigned int mode, unsigned int num);
-  //@}
+  void AddColorAttachment(unsigned int attId, vtkTextureObject* tex, unsigned int zslice = 0,
+    unsigned int format = 0, unsigned int mipmapLevel = 0);
+  void AddColorAttachment(unsigned int attId, vtkRenderbuffer* tex);
+  void RemoveColorAttachment(unsigned int index);
+  void RemoveColorAttachments(unsigned int num);
+  ///@}
+
+  /**
+   * Return the texture object bound to the passed attachment number.
+   * In the case that a renderbuffer is used, this will return nullptr.
+   */
+  vtkTextureObject* GetColorAttachmentAsTextureObject(unsigned int num);
 
   /**
    * Return the number of color attachments for the given mode
    */
-  int GetNumberOfColorAttachments(unsigned int mode);
+  int GetNumberOfColorAttachments();
 
-  //@{
+  ///@{
   /**
    * Directly assign/remove a texture/renderbuffer to depth attachments.
    */
-  void AddDepthAttachment() {
-    this->AddDepthAttachment(this->GetBothMode()); }
-  void AddDepthAttachment(unsigned int mode);
-  void AddDepthAttachment(unsigned int mode, vtkTextureObject* tex);
-  void AddDepthAttachment(unsigned int mode, vtkRenderbuffer* tex);
-  void RemoveDepthAttachment(unsigned int mode);
-  //@}
+  void AddDepthAttachment();
+  void AddDepthAttachment(vtkTextureObject* tex);
+  void AddDepthAttachment(vtkRenderbuffer* tex);
+  void RemoveDepthAttachment();
+  vtkTextureObject* GetDepthAttachmentAsTextureObject();
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convenience method to populate a framebuffer with
    * attachments created as well. Returns true if a
-   * complete valid Frambuffer was created
+   * complete valid Framebuffer was created
    */
   bool PopulateFramebuffer(int width, int height);
-  bool PopulateFramebuffer(
-    int width,
-    int height,
-    bool useTextures,
-    int numberOfColorAttachments,
-    int colorDataType,
-    bool wantDepthAttachment,
-    int depthBitplanes,
-    int multisamples);
-  //@}
+  bool PopulateFramebuffer(int width, int height, bool useTextures, int numberOfColorAttachments,
+    int colorDataType, bool wantDepthAttachment, int depthBitplanes, int multisamples,
+    bool wantStencilAttachment = false);
+  ///@}
 
   /**
    * Returns the maximum number of targets that can be rendered to at one time.
@@ -362,38 +313,36 @@ public:
 
   /**
    * Returns the maximum number of render targets available. This limits the
-   * available attachement points for SetColorAttachment().
+   * available attachment points for SetColorAttachment().
    * The return value is valid only if GetContext is non-null.
    */
   unsigned int GetMaximumNumberOfRenderTargets();
 
-  //@{
+  ///@{
   /**
    * Dimensions in pixels of the framebuffer.
    */
-  int *GetLastSize() override
+  int* GetLastSize() override
   {
-    vtkDebugMacro(<< this->GetClassName() << " (" << this << "): returning LastSize pointer " << this->LastSize);
+    vtkDebugMacro(<< this->GetClassName() << " (" << this << "): returning LastSize pointer "
+                  << this->LastSize);
     return this->LastSize;
   }
-  void GetLastSize(int &_arg1, int &_arg2) override
+  void GetLastSize(int& _arg1, int& _arg2) override
   {
-      _arg1 = this->LastSize[0];
-      _arg2 = this->LastSize[1];
-    vtkDebugMacro(<< this->GetClassName() << " (" << this << "): returning LastSize (" << _arg1 << "," << _arg2 << ")");
+    _arg1 = this->LastSize[0];
+    _arg2 = this->LastSize[1];
+    vtkDebugMacro(<< this->GetClassName() << " (" << this << "): returning LastSize (" << _arg1
+                  << "," << _arg2 << ")");
   }
-  void GetLastSize (int _arg[2]) override
-  {
-    this->GetLastSize (_arg[0], _arg[1]);
-  }
-  //@}
+  void GetLastSize(int _arg[2]) override { this->GetLastSize(_arg[0], _arg[1]); }
+  ///@}
 
   /**
    * Returns if the context supports the required extensions.
-   * Extension will be loaded when the conetxt is set.
+   * Extension will be loaded when the context is set.
    */
-  static bool IsSupported(vtkOpenGLRenderWindow *) {
-      return true; }
+  static bool IsSupported(vtkOpenGLRenderWindow*) { return true; }
 
   /**
    * Validate the current FBO configuration (attachments, formats, etc)
@@ -404,7 +353,7 @@ public:
   /**
    * Deactivate and UnBind
    */
-  virtual void ReleaseGraphicsResources(vtkWindow *win);
+  virtual void ReleaseGraphicsResources(vtkWindow* win);
 
   /**
    * Validate the current FBO configuration (attachments, formats, etc)
@@ -412,12 +361,11 @@ public:
    * containing a description of the status.
    * Low level api.
    */
-  static
-  bool GetFrameBufferStatus(
-        unsigned int mode,
-        const char *&desc);
+  static bool GetFrameBufferStatus(unsigned int mode, const char*& desc);
 
-    /**
+  vtkGetMacro(FBOIndex, unsigned int);
+
+  /**
    * Copy from the currently bound READ FBO to the currently
    * bound DRAW FBO. The method is static so that one doesn't
    * need to ccreate an instance when transferring between attachments
@@ -428,56 +376,37 @@ public:
 
   /**
    * Download data from the read color attachment of the currently
-   * bound FBO into the retruned PBO. The PBO must be free'd when
+   * bound FBO into the returned PBO. The PBO must be free'd when
    * you are finished with it. The number of components in the
    * PBO is the same as in the name of the specific download function.
    * When downloading a single color channel, the channel must be
    * identified by index, 1->red, 2->green, 3-> blue.
    */
-  vtkPixelBufferObject *DownloadColor1(
-        int extent[4],
-        int vtkType,
-        int channel);
+  vtkPixelBufferObject* DownloadColor1(int extent[4], int vtkType, int channel);
 
-  vtkPixelBufferObject *DownloadColor3(
-        int extent[4],
-        int vtkType);
+  vtkPixelBufferObject* DownloadColor3(int extent[4], int vtkType);
 
-  vtkPixelBufferObject *DownloadColor4(
-        int extent[4],
-        int vtkType);
+  vtkPixelBufferObject* DownloadColor4(int extent[4], int vtkType);
 
   /**
    * Download data from the depth attachment of the currently
    * bound FBO. The returned PBO must be Delete'd by the caller.
-   * The retruned PBO has one component.
+   * The returned PBO has one component.
    */
-  vtkPixelBufferObject *DownloadDepth(
-        int extent[4],
-        int vtkType);
+  vtkPixelBufferObject* DownloadDepth(int extent[4], int vtkType);
 
   /**
    * Download data from the read buffer of the current FBO. These
-   * are low level meothds. In the static variant a PBO must be
+   * are low level methods. In the static variant a PBO must be
    * passed in since we don't have access to a context. The static
    * method is provided so that one may download from the default
    * FBO.
    */
-  vtkPixelBufferObject *Download(
-        int extent[4],
-        int vtkType,
-        int nComps,
-        int oglType,
-        int oglFormat);
+  vtkPixelBufferObject* Download(
+    int extent[4], int vtkType, int nComps, int oglType, int oglFormat);
 
-  static
-  void Download(
-        int extent[4],
-        int vtkType,
-        int nComps,
-        int oglType,
-        int oglFormat,
-        vtkPixelBufferObject *pbo);
+  static void Download(
+    int extent[4], int vtkType, int nComps, int oglType, int oglFormat, vtkPixelBufferObject* pbo);
 
   // returns the mode values for draw/read/both
   // Can be used in cases where you do not
@@ -491,54 +420,31 @@ public:
    */
   void Resize(int width, int height);
 
-  // Deprecated
-  void RemoveTexColorAttachments(unsigned int mode, unsigned int num)
-    { this->RemoveColorAttachments(mode, num); }
-  void RemoveTexColorAttachment(unsigned int mode, unsigned int attId)
-    { this->RemoveColorAttachment(mode, attId); }
-  void RemoveRenDepthAttachment(unsigned int mode)
-    { this->RemoveDepthAttachment(mode); }
-  void RemoveTexDepthAttachment(unsigned int mode)
-    { this->RemoveDepthAttachment(mode); }
+  int GetMultiSamples();
 
 protected:
-  void SetColorBuffer(unsigned int mode,
-    unsigned int index, vtkTextureObject *texture,
-    unsigned int zslice=0);
-  void SetColorBuffer(unsigned int mode,
-    unsigned int index, vtkRenderbuffer *rb);
-  void SetDepthBuffer(unsigned int mode, vtkTextureObject *depthTexture);
-  void SetDepthBuffer(unsigned int mode, vtkRenderbuffer *depthBuffer);
-
-  /**
-   * Attach all buffers to the FO if not already done so
-   */
-  void Attach();
-
   /**
    * Attach a specific buffer
    */
-  void AttachColorBuffer(unsigned int mode, unsigned int index);
-  void AttachDepthBuffer(unsigned int mode);
+  void AttachColorBuffer(unsigned int index);
+  void AttachDepthBuffer();
 
   /**
    * Load all necessary extensions.
    */
-  static
-  bool LoadRequiredExtensions(vtkOpenGLRenderWindow *) {
-    return true; };
+  static bool LoadRequiredExtensions(vtkOpenGLRenderWindow*) { return true; }
 
-  vtkGenericOpenGLResourceFreeCallback *ResourceCallback;
+  vtkGenericOpenGLResourceFreeCallback* ResourceCallback;
 
   // gen buffer (occurs when context is set)
   void CreateFBO();
 
-  // delete buffer (occurs during destruction or context swicth)
+  // delete buffer (occurs during destruction or context switch)
   void DestroyFBO();
 
   // detach and delete our reference(s)
-  void DestroyDepthBuffer(vtkWindow *win);
-  void DestroyColorBuffers(vtkWindow *win);
+  void DestroyDepthBuffer(vtkWindow* win);
+  void DestroyColorBuffers(vtkWindow* win);
 
   // glDrawBuffers
   void ActivateBuffers();
@@ -571,7 +477,7 @@ protected:
    */
   void DisplayBuffer(int value);
 
-    /**
+  /**
    * Given a vtk type get a compatible open gl type.
    */
   int GetOpenGLType(int vtkType);
@@ -579,30 +485,26 @@ protected:
   vtkOpenGLFramebufferObject();
   ~vtkOpenGLFramebufferObject() override;
 
-  vtkWeakPointer<vtkOpenGLRenderWindow> Context;
+  vtkOpenGLRenderWindow* Context;
 
   unsigned int FBOIndex;
 
-  unsigned int PreviousDrawFBO;
-  unsigned int PreviousReadFBO;
   bool DrawBindingSaved;
   bool ReadBindingSaved;
-  unsigned int PreviousDrawBuffer;
-  unsigned int PreviousReadBuffer;
   bool DrawBufferSaved;
   bool ReadBufferSaved;
 
   int LastSize[2];
   std::vector<unsigned int> ActiveBuffers;
+  unsigned int ActiveReadBuffer;
 
-  vtkFOInfo *DrawDepthBuffer;
-  vtkFOInfo *ReadDepthBuffer;
-  std::map<unsigned int, vtkFOInfo *> DrawColorBuffers;
-  std::map<unsigned int, vtkFOInfo *> ReadColorBuffers;
+  vtkFOInfo* DepthBuffer;
+  std::map<unsigned int, vtkFOInfo*> ColorBuffers;
 
 private:
   vtkOpenGLFramebufferObject(const vtkOpenGLFramebufferObject&) = delete;
   void operator=(const vtkOpenGLFramebufferObject&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
