@@ -7,7 +7,7 @@
 #  define VTKRENDERINGCORE_NO_EXPORT
 #else
 #  ifndef VTKRENDERINGCORE_EXPORT
-#    ifdef vtkRenderingCore_EXPORTS
+#    ifdef RenderingCore_EXPORTS
         /* We are building this library */
 #      define VTKRENDERINGCORE_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,25 +23,37 @@
 
 #ifndef VTKRENDERINGCORE_DEPRECATED
 #  define VTKRENDERINGCORE_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKRENDERINGCORE_DEPRECATED_EXPORT VTKRENDERINGCORE_EXPORT __attribute__ ((__deprecated__))
-#  define VTKRENDERINGCORE_DEPRECATED_NO_EXPORT VTKRENDERINGCORE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKRENDERINGCORE_NO_DEPRECATED
+#ifndef VTKRENDERINGCORE_DEPRECATED_EXPORT
+#  define VTKRENDERINGCORE_DEPRECATED_EXPORT VTKRENDERINGCORE_EXPORT VTKRENDERINGCORE_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
+#ifndef VTKRENDERINGCORE_DEPRECATED_NO_EXPORT
+#  define VTKRENDERINGCORE_DEPRECATED_NO_EXPORT VTKRENDERINGCORE_NO_EXPORT VTKRENDERINGCORE_DEPRECATED
+#endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKRENDERINGCORE_NO_DEPRECATED
+#    define VTKRENDERINGCORE_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkRenderingCoreModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+/* AutoInit dependencies. */
 #include "vtkFiltersCoreModule.h"
 
-/* AutoInit implementations.  */
-#if defined(vtkRenderingCore_INCLUDE)
-# include vtkRenderingCore_INCLUDE
+
+/* AutoInit implementations. */
+#ifdef vtkRenderingCore_AUTOINIT_INCLUDE
+#include vtkRenderingCore_AUTOINIT_INCLUDE
 #endif
-#if defined(vtkRenderingCore_AUTOINIT)
-# include "vtkAutoInit.h"
-VTK_AUTOINIT(vtkRenderingCore)
+#ifdef vtkRenderingCore_AUTOINIT
+#include "vtkAutoInit.h"
+VTK_MODULE_AUTOINIT(vtkRenderingCore)
 #endif
 
-#endif
+#endif /* VTKRENDERINGCORE_EXPORT_H */
