@@ -7,7 +7,7 @@
 #  define VTKRENDERINGLABEL_NO_EXPORT
 #else
 #  ifndef VTKRENDERINGLABEL_EXPORT
-#    ifdef vtkRenderingLabel_EXPORTS
+#    ifdef RenderingLabel_EXPORTS
         /* We are building this library */
 #      define VTKRENDERINGLABEL_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,17 +23,25 @@
 
 #ifndef VTKRENDERINGLABEL_DEPRECATED
 #  define VTKRENDERINGLABEL_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKRENDERINGLABEL_DEPRECATED_EXPORT VTKRENDERINGLABEL_EXPORT __attribute__ ((__deprecated__))
-#  define VTKRENDERINGLABEL_DEPRECATED_NO_EXPORT VTKRENDERINGLABEL_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKRENDERINGLABEL_NO_DEPRECATED
+#ifndef VTKRENDERINGLABEL_DEPRECATED_EXPORT
+#  define VTKRENDERINGLABEL_DEPRECATED_EXPORT VTKRENDERINGLABEL_EXPORT VTKRENDERINGLABEL_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkRenderingCoreModule.h"
-#include "vtkRenderingFreeTypeModule.h"
-
+#ifndef VTKRENDERINGLABEL_DEPRECATED_NO_EXPORT
+#  define VTKRENDERINGLABEL_DEPRECATED_NO_EXPORT VTKRENDERINGLABEL_NO_EXPORT VTKRENDERINGLABEL_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKRENDERINGLABEL_NO_DEPRECATED
+#    define VTKRENDERINGLABEL_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkRenderingLabelModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKRENDERINGLABEL_EXPORT_H */
