@@ -7,7 +7,7 @@
 #  define VTKRENDERINGSCENEGRAPH_NO_EXPORT
 #else
 #  ifndef VTKRENDERINGSCENEGRAPH_EXPORT
-#    ifdef vtkRenderingSceneGraph_EXPORTS
+#    ifdef RenderingSceneGraph_EXPORTS
         /* We are building this library */
 #      define VTKRENDERINGSCENEGRAPH_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,25 @@
 
 #ifndef VTKRENDERINGSCENEGRAPH_DEPRECATED
 #  define VTKRENDERINGSCENEGRAPH_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKRENDERINGSCENEGRAPH_DEPRECATED_EXPORT VTKRENDERINGSCENEGRAPH_EXPORT __attribute__ ((__deprecated__))
-#  define VTKRENDERINGSCENEGRAPH_DEPRECATED_NO_EXPORT VTKRENDERINGSCENEGRAPH_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKRENDERINGSCENEGRAPH_NO_DEPRECATED
+#ifndef VTKRENDERINGSCENEGRAPH_DEPRECATED_EXPORT
+#  define VTKRENDERINGSCENEGRAPH_DEPRECATED_EXPORT VTKRENDERINGSCENEGRAPH_EXPORT VTKRENDERINGSCENEGRAPH_DEPRECATED
 #endif
 
-
-
+#ifndef VTKRENDERINGSCENEGRAPH_DEPRECATED_NO_EXPORT
+#  define VTKRENDERINGSCENEGRAPH_DEPRECATED_NO_EXPORT VTKRENDERINGSCENEGRAPH_NO_EXPORT VTKRENDERINGSCENEGRAPH_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKRENDERINGSCENEGRAPH_NO_DEPRECATED
+#    define VTKRENDERINGSCENEGRAPH_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkRenderingSceneGraphModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKRENDERINGSCENEGRAPH_EXPORT_H */
