@@ -7,7 +7,7 @@
 #  define VTKTESTINGGENERICBRIDGE_NO_EXPORT
 #else
 #  ifndef VTKTESTINGGENERICBRIDGE_EXPORT
-#    ifdef vtkTestingGenericBridge_EXPORTS
+#    ifdef TestingGenericBridge_EXPORTS
         /* We are building this library */
 #      define VTKTESTINGGENERICBRIDGE_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,25 @@
 
 #ifndef VTKTESTINGGENERICBRIDGE_DEPRECATED
 #  define VTKTESTINGGENERICBRIDGE_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKTESTINGGENERICBRIDGE_DEPRECATED_EXPORT VTKTESTINGGENERICBRIDGE_EXPORT __attribute__ ((__deprecated__))
-#  define VTKTESTINGGENERICBRIDGE_DEPRECATED_NO_EXPORT VTKTESTINGGENERICBRIDGE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKTESTINGGENERICBRIDGE_NO_DEPRECATED
+#ifndef VTKTESTINGGENERICBRIDGE_DEPRECATED_EXPORT
+#  define VTKTESTINGGENERICBRIDGE_DEPRECATED_EXPORT VTKTESTINGGENERICBRIDGE_EXPORT VTKTESTINGGENERICBRIDGE_DEPRECATED
 #endif
 
-
-
+#ifndef VTKTESTINGGENERICBRIDGE_DEPRECATED_NO_EXPORT
+#  define VTKTESTINGGENERICBRIDGE_DEPRECATED_NO_EXPORT VTKTESTINGGENERICBRIDGE_NO_EXPORT VTKTESTINGGENERICBRIDGE_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKTESTINGGENERICBRIDGE_NO_DEPRECATED
+#    define VTKTESTINGGENERICBRIDGE_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkTestingGenericBridgeModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKTESTINGGENERICBRIDGE_EXPORT_H */
