@@ -7,7 +7,7 @@
 #  define VTKVIEWSQT_NO_EXPORT
 #else
 #  ifndef VTKVIEWSQT_EXPORT
-#    ifdef vtkViewsQt_EXPORTS
+#    ifdef ViewsQt_EXPORTS
         /* We are building this library */
 #      define VTKVIEWSQT_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,18 +23,25 @@
 
 #ifndef VTKVIEWSQT_DEPRECATED
 #  define VTKVIEWSQT_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKVIEWSQT_DEPRECATED_EXPORT VTKVIEWSQT_EXPORT __attribute__ ((__deprecated__))
-#  define VTKVIEWSQT_DEPRECATED_NO_EXPORT VTKVIEWSQT_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKVIEWSQT_NO_DEPRECATED
+#ifndef VTKVIEWSQT_DEPRECATED_EXPORT
+#  define VTKVIEWSQT_DEPRECATED_EXPORT VTKVIEWSQT_EXPORT VTKVIEWSQT_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkGUISupportQtModule.h"
-#include "vtkViewsCoreModule.h"
-#include "vtkViewsInfovisModule.h"
-
+#ifndef VTKVIEWSQT_DEPRECATED_NO_EXPORT
+#  define VTKVIEWSQT_DEPRECATED_NO_EXPORT VTKVIEWSQT_NO_EXPORT VTKVIEWSQT_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKVIEWSQT_NO_DEPRECATED
+#    define VTKVIEWSQT_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkViewsQtModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKVIEWSQT_EXPORT_H */
